<img src="docs/_static/logo.svg" width="50%" />

[![PyPI version](https://badge.fury.io/py/plopp.svg)](https://pypi.org/project/plopp)
[![Anaconda-Server Badge](https://anaconda.org/scipp/plopp/badges/version.svg)](https://anaconda.org/scipp/plopp)
[![Documentation](https://img.shields.io/badge/docs-online-success)](https://scipp.github.io/plopp/)
[![License: BSD 3-Clause](https://img.shields.io/badge/License-BSD%203--Clause-blue.svg)](LICENSE)
[![DOI](https://zenodo.org/badge/528859752.svg)](https://zenodo.org/badge/latestdoi/528859752)

# Plopp

Plotting library based on scipp.

## Documentation

The documentation for `plopp` can be found at https://scipp.github.io/plopp.

## Installation

### Using pip

```sh
pip install plopp
```

### Using conda

```sh
conda install -c conda-forge -c scipp plopp
```

## Have a problem or need a new feature?

- Bug reports or feature requests should be submitted by opening an [issue](https://github.com/scipp/plopp/issues)
- For general discussions or questions about how to do something with `plopp`, start a new [discussion](https://github.com/scipp/plopp/discussions)
